@@ -17,7 +17,7 @@ def mesh_is_connected(mesh):
 
     Parameters
     ----------
-    mesh : compas.datastructures.Mesh
+    mesh : :class:`~compas.datastructures.Mesh`
         A mesh data structure.
 
     Returns
@@ -44,6 +44,7 @@ def mesh_is_connected(mesh):
     >>> abc = mesh.add_face([a, b, c])
     >>> mesh_is_connected(mesh)
     True
+
     """
     if not mesh.vertex:
         return False
@@ -52,4 +53,17 @@ def mesh_is_connected(mesh):
 
 
 def mesh_connected_components(mesh):
+    """Find the connected components of the mesh.
+
+    Parameters
+    ----------
+    mesh : :class:`~compas.datastructures.Mesh`
+        A mesh data structure.
+
+    Returns
+    -------
+    list[list[int]]
+        Groups of connected vertices.
+
+    """
     return connected_components(mesh.adjacency)
